@@ -19,7 +19,7 @@ import warnings
 from ctypes.util import find_library
 from abc import ABC, abstractmethod
 
-__version__ = "2.1.0"
+__version__ = "2.2.0"
 __all__ = ["threadpool_limits", "threadpool_info"]
 
 
@@ -212,8 +212,8 @@ class threadpool_limits:
 
         if warning_apis:
             warnings.warn(
-                "Multiple value possible for following user apis: "
-                + ", ".join(warning_apis) + ". Returning the minimum.")
+                "Multiple value possible for following user apis: " +
+                ", ".join(warning_apis) + ". Returning the minimum.")
 
         return num_threads
 
@@ -660,6 +660,7 @@ class _OpenBLASModule(_Module):
 
     def _get_extra_info(self):
         self.threading_layer = self.get_threading_layer()
+        self.architecture = self.get_architecture()
 
     def get_threading_layer(self):
         """Return the threading layer of OpenBLAS"""
@@ -670,6 +671,14 @@ class _OpenBLASModule(_Module):
             return "pthreads"
         return "disabled"
 
+    def get_architecture(self):
+        get_corename = getattr(self._dynlib, "openblas_get_corename", None)
+        if get_corename is None:
+            return None
+
+        get_corename.restype = ctypes.c_char_p
+        return get_corename().decode("utf-8")
+
 
 class _BLISModule(_Module):
     """Module class for BLIS"""
@@ -694,6 +703,7 @@ class _BLISModule(_Module):
 
     def _get_extra_info(self):
         self.threading_layer = self.get_threading_layer()
+        self.architecture = self.get_architecture()
 
     def get_threading_layer(self):
         """Return the threading layer of BLIS"""
@@ -703,12 +713,27 @@ class _BLISModule(_Module):
             return "pthreads"
         return "disabled"
 
+    def get_architecture(self):
+        bli_arch_query_id = getattr(self._dynlib, "bli_arch_query_id", None)
+        bli_arch_string = getattr(self._dynlib, "bli_arch_string", None)
+        if bli_arch_query_id is None or bli_arch_string is None:
+            return None
+
+        # the true restype should be BLIS' arch_t (enum) but int should work
+        # for us:
+        bli_arch_query_id.restype = ctypes.c_int
+        bli_arch_string.restype = ctypes.c_char_p
+        return bli_arch_string(bli_arch_query_id()).decode("utf-8")
+
 
 class _MKLModule(_Module):
     """Module class for MKL"""
     def get_version(self):
+        if not hasattr(self._dynlib, "MKL_Get_Version_String"):
+            return None
+
         res = ctypes.create_string_buffer(200)
-        self._dynlib.mkl_get_version_string(res, 200)
+        self._dynlib.MKL_Get_Version_String(res, 200)
 
         version = res.value.decode("utf-8")
         group = re.search(r"Version ([^ ]+) ", version)
